@@ -30,6 +30,7 @@ from sereto.exceptions import SeretoException, SeretoPathError, SeretoValueError
 from sereto.keyring import get_password, set_password
 from sereto.models.settings import Settings
 from sereto.models.version import ProjectVersion
+from sereto.oxipng import run_oxipng
 from sereto.pdf import generate_pdf_finding_group, generate_pdf_report, generate_pdf_sow, generate_pdf_target
 from sereto.project import Project, new_project
 from sereto.retest import add_retest
@@ -140,6 +141,15 @@ def clean(ctx: Project) -> None:
         shutil.rmtree(build_dir)
 
 
+@cli.command()
+@handle_exceptions
+@click.pass_obj
+@validate_call
+def oxipng(ctx: Project) -> None:
+    """Lossless PNGs compression."""
+    run_oxipng(project_path=ctx.path)
+
+
 # -------------
 # sereto config
 # -------------
@@ -529,10 +539,9 @@ def open_report(ctx: Project, version: ProjectVersion | None) -> None:
         ctx: Project's representation.
         version: The version of the report that is opened. If None, the last version is used.
     """
-    if version is None:
-        version = ctx.config.last_version
+    version_config = ctx.config.at_version(version) if version else ctx.config.last_config
 
-    if not (report_path := ctx.path / "pdf" / f"report{version.path_suffix}.pdf").is_file():
+    if not (report_path := ctx.path / "pdf" / version_config.report_name).is_file():
         raise SeretoPathError(f"File not found '{report_path}'")
 
     click.launch(str(report_path))
@@ -550,10 +559,9 @@ def open_sow(ctx: Project, version: ProjectVersion | None) -> None:
         ctx: Project's representation.
         version: The version of the SoW that is opened. If None, the last version is used.
     """
-    if version is None:
-        version = ctx.config.last_version
+    version_config = ctx.config.at_version(version) if version else ctx.config.last_config
 
-    if not (sow_path := ctx.path / "pdf" / f"sow{version.path_suffix}.pdf").is_file():
+    if not (sow_path := ctx.path / "pdf" / version_config.sow_name).is_file():
         raise SeretoPathError(f"File not found '{sow_path}'")
 
     click.launch(str(sow_path))
